#!/bin/bash
#
# This script installs devlabel
# devlabel by Gary Lerhaupt

if [ `dirname $0 | grep -c "^/"` -gt 0 ]; then
    DIR=`dirname $0`
else
    DIR=`pwd``dirname $0 | sed 's/^\.//'`
fi


USERID=`id -u`
if [ "$USERID" -ne 0 ]; then 
	echo "Must be root to install."
fi

echo ""
echo "If build of partition_uuid fails, it is probably because"
echo "you do not have uuid.h installed.  This file can be"
echo "found in the e2fsprogs-devel package."
echo "" 

echo "Making scsi_unique_id"
echo "  gcc -O2 -o scsi_unique_id scsi_unique_id.c"
gcc -O2 -o $DIR/scsi_unique_id $DIR/scsi_unique_id.c
echo "Installing scsi_unique_id"
cp -f $DIR/scsi_unique_id /usr/bin/
chmod 755 /usr/bin/scsi_unique_id

echo "Make partition_uuid"
echo "  gcc -O2 -o partition_uuid -luuid partition_uuid.c"
gcc -O2 -o $DIR/partition_uuid -luuid $DIR/partition_uuid.c
echo "Installing partition_uuid"
cp -f $DIR/partition_uuid /usr/bin/
chmod 755 /usr/bin/partition_uuid

# Detect old version of devlabel
if [ -e /etc/sysconfig/devlabel ]; then
	devlabel_version=`devlabel -v 2>/dev/null`
	old_format=""
	version_major=`echo $devlabel_version | awk {'print $2'} | cut -d '.' -f 1-1`
	version_minor=`echo $devlabel_version | awk {'print $2'} | cut -d '.' -f 2-2`
	[ -z "$version_minor" ] && old_format="true"
	[ -z "$old_format" ] && [ "$version_major" -eq 0 ] && [ "$version_minor" -lt 37 ] && old_format="true"	
	if [ -n "$old_format" ]; then
		echo ""
		echo "Warning! An old version of devlabel was detected which uses the old uuid format."
		echo "devlabel will restart and later run a reverseremap to fix your UUIDs."
                /sbin/devlabel restart >/dev/null 2>&1
        fi
fi

echo "Installing devlabel"
cp -f $DIR/devlabel /sbin
rm -f /usr/share/man/man8/devlabel.8 2>/dev/null
cp -f $DIR/devlabel.8.gz /usr/share/man/man8
mkdir -p /var/lib/devlabel
mkdir -p /etc/sysconfig/devlabel.d
cp -f $DIR/ignore_list /var/lib/devlabel/ignore_list
if ! [ -e /etc/sysconfig/devlabel ]; then
	cp -f $DIR/sysconfig.devlabel /etc/sysconfig/devlabel
	cp -f /etc/sysconfig/devlabel /etc/sysconfig/devlabel.0
fi
chmod 755 /sbin/devlabel

if [ -n "$old_format" ]; then
	echo ""
	echo "Running a reverseremap to fix your UUIDs:"
	devlabel reverseremap --force
fi

echo ""
echo "If you have not already done so, be sure to manually patch rc.sysinit"
echo "and your hotplug agent scripts."
